import rclpy
from rclpy.node import Node

from std_msgs.msg import Float32

from serial import Serial

from enum import Enum

class Servos(Enum):
    J1 = 'A'
    J2 = 'B'
    J3 = 'C'

class CobotMove(Node):
    def __init__(self):
        super().__init__('cobot_move')
        self._logger = self.get_logger()
        self._logger.info('COBOT init')

        self._serial = Serial('/dev/ttyACM0', 115200)

        # self._buf = [90, 90, 90] # 3 servos
        # self._prev_buf = [90, 90, 90]

        base_topic = 'move/'

        self.create_subscription(Float32, base_topic+'j1', self._move_j1_cb, rclpy.qos.qos_profile_sensor_data)
        self.create_subscription(Float32, base_topic+'j2',  self._move_j2_cb,  rclpy.qos.qos_profile_sensor_data)
        self.create_subscription(Float32, base_topic+'j3', self._move_j3_cb, rclpy.qos.qos_profile_sensor_data)

        self._serial.write(b'STA0.0.1\n')
        print(self._serial.readline())

    def _move_j1_cb(self, msg):
        self._move_servo(Servos.J1, msg.data)

    def _move_j2_cb(self, msg):
        self._move_servo(Servos.J2, msg.data)

    def _move_j3_cb(self, msg):
        self._move_servo(Servos.J3, msg.data)

    def _move_servo(self, serv_num, pos):
        cmd = 'MT'
        #  self._buf[serv_num] = pos
        self._serial.write(f'{cmd}A{int(pos * 10000)}B0C0D0E0F0\n'.encode('UTF-8'))
        print(self._serial.readline())

    # def _push ?

def main(args=None):
    rclpy.init(args=args)

    cobot_move = CobotMove()
    rclpy.spin(cobot_move)

    cobot_move.destroy_node()
    rclpy.shutdown()


if __name__ == '__main__':
    main()
